@@ -4,6 +4,7 @@ from trex.stl.api import *
 from snappi_trex.validation import Validation
 from snappi_trex.setconfig import SetConfig
 from snappi_trex.capture import Capture
+from snappi_trex.metrics import Metrics
 
 
 class Api(snappi.Api):
@@ -34,6 +35,7 @@ class Api(snappi.Api):
         self._port_ids = []
         self._transmit_states = {}
         self._capture = Capture(self._c)
+        self._metrics = Metrics(self._c)
 
         try:
             # connect to server
@@ -45,10 +47,15 @@ class Api(snappi.Api):
     # try to disconnect when object is deleted
     def __del__(self):
         try:
+            self.wait_on_traffic(list(range(len(self._port_ids))))
             self._c.disconnect()
         except STLError as e:
             print(e)
 
+    
+    def wait_on_traffic(self, ports):
+        self._c.wait_on_traffic(ports = ports)
+
 
     # Maps port names used in Snappi to port index for T-Rex
     def _loadPorts(self):
@@ -170,11 +177,24 @@ class Api(snappi.Api):
             if len(ports_pause) > 0:
                 self._c.pause(ports = ports_pause)
 
-            self._c.wait_on_traffic(ports = ports)
         except STLError as e:
             self._c.disconnect()
             print(e)
 
+
+    def set_link_state(self, payload):
+        ls = json.loads(payload.serialize())
+        ports = list(range(len(self._port_ids)))
+        if ls['port_names'] is not None:
+            ports = []
+            for p_name in ls['port_names']:
+                ports.append(self._port_ids.index(p_name))
+
+        if ls['state'] == 'up':
+            self._c.set_port_attr(ports=ports, link_up=True)
+        elif ls['state'] == 'down':
+            self._c.set_port_attr(ports=ports, link_up=False)
+
     
     def set_capture_state(self, payload):
         """Starts capture on all ports that have capture enabled.
@@ -206,6 +226,7 @@ class Api(snappi.Api):
           #/components/schemas/Result.MetricsRequest
           See the docs/openapi.yaml document for all model details
         """
+        return self._metrics.get_metrics(request, self._port_ids, self._capture)
 
 
     def get_config(self):
