@@ -89,36 +89,6 @@ class Validation(object):
                         header_field = header['ipv4'][field]
                     Validation.validate_value_option(header_field, 'IP', field_info['length'])
 
-                # if 'src' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['src'], 'IP', 32)
-                # if 'dst' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['dst'], 'IP', 32)
-                # if 'version' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['version'], 'IP', 4)
-                # if 'header_length' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['header_length'], 'IP', 4)
-                # if 'priority' in header['ipv4']:
-                #     if 'raw' in header['ipv4']['priority']:
-                #         Validation.validate_value_option(header['ipv4']['priority']['raw'], 'IP', 8)
-                #     else:
-                #         raise SnappiTrexException('ipv4 \'priority\' only supports \'raw\' option')
-                # if 'total_length' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['total_length'], 'IP', 16)
-                # if 'identification' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['identification'], 'IP', 16)
-                # if 'reserved' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['reserved'], 'IP', 1)
-                # if 'dont_fragment' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['dont_fragment'], 'IP', 1)
-                # if 'more_fragments' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['more_fragments'], 'IP', 1)
-                # if 'fragment_offset' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['fragment_offset'], 'IP', 13)
-                # if 'time_to_live' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['time_to_live'], 'IP', 8)
-                # if 'protocol' in header['ipv4']:
-                #     Validation.validate_value_option(header['ipv4']['protocol'], 'IP', 8)
-
             elif header['choice'] == 'udp':
                 for field in header['udp']:
                     if field not in header_info['udp']:
@@ -126,13 +96,6 @@ class Validation(object):
                     field_info = header_info['udp'][field]
                     Validation.validate_value_option(header['udp'][field], 'UDP', field_info['length'])
 
-                # if 'src_port' in header['udp']:
-                #     Validation.validate_value_option(header['udp']['src_port'], 'UDP', 16)
-                # if 'dst_port' in header['udp']:
-                #     Validation.validate_value_option(header['udp']['dst_port'], 'UDP', 16)
-                # if 'length' in header['udp']:
-                #     Validation.validate_value_option(header['udp']['length'], 'UDP', 16)
-
             elif header['choice'] == 'tcp':
                 for field in header['tcp']:
                     if field not in header_info['tcp']:
@@ -140,36 +103,6 @@ class Validation(object):
                     field_info = header_info['tcp'][field]
                     Validation.validate_value_option(header['tcp'][field], 'TCP', field_info['length'])
 
-            #     if 'src_port' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['src_port'], 'TCP', 16)
-            #     if 'dst_port' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['dst_port'], 'TCP', 16)
-            #     if 'seq_num' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['seq_num'], 'TCP', 32)
-            #     if 'ack_num' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ack_num'], 'TCP', 32)
-            #     if 'data_offset' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['data_offset'], 'TCP', 4)
-            #     if 'ecn_ns' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ecn_ns'], 'TCP', 1)
-            #     if 'ecn_cwr' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ecn_cwr'], 'TCP', 1)
-            #     if 'ecn_echo' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ecn_echo'], 'TCP', 1)
-            #     if 'ctl_urg' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_urg'], 'TCP', 1)
-            #     if 'ctl_ack' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_ack'], 'TCP', 1)
-            #     if 'ctl_psh' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_psh'], 'TCP', 1)
-            #     if 'ctl_rst' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_rst'], 'TCP', 1)
-            #     if 'ctl_syn' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_syn'], 'TCP', 1)
-            #     if 'ctl_fin' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['ctl_fin'], 'TCP', 1)
-            #     if 'window' in header['tcp']:
-            #         Validation.validate_value_option(header['tcp']['window'], 'TCP', 16)
             else:
                 raise SnappiTrexException('Invalid packet \'header\' choice')
 
@@ -240,3 +173,21 @@ class Validation(object):
             error = True
         if error:
             raise SnappiTrexException('{0} is not a valid {1} address'.format(addr, layer_type))
+
+
+    def validate_capture(payload, port_ids):
+        if payload.port_names is not None:
+            for p_name in payload.port_names:
+                if p_name not in port_ids:
+                    raise SnappiTrexException('{} is an unrecognized port name'.format(p_name))
+        if (payload.state != 'start') and (payload.state != 'stop'):
+            raise SnappiTrexException('{} is not a valid capture state'.format(payload.state))
+
+
+    def validate_capture_request(request, port_ids):
+        p_name = request.port_name
+        if p_name not in port_ids:
+            raise SnappiTrexException('{} is an unrecognized port name'.format(p_name))
+
+
+
